function [H] = Bending_Hessian_Analytic(T)
  mu = 1;
  theta0 = pi / 2;

  t0 = T(:,1);
  t1 = T(:,2);
  b = cross(t0,t1);
  b0 = cross(t0,b / norm(b));
  b1 = cross(t1,b / norm(b));

  cosTheta = dot(t0,t1);
  theta = acos(cosTheta);

  dTheta = mu * (theta - theta0);
  ddTheta = mu;

  diffSq = (theta - theta0) * (theta - theta0);
  lambdas = zeros(6,1);
  lambdas(1) = dTheta * (cosTheta - 1) / norm(b);
  lambdas(2) = dTheta * (cosTheta + 1) / norm(b);
  lambdas(3) = mu * (1 + sqrt(1 + diffSq));
  lambdas(4) = mu * (1 - sqrt(1 + diffSq));
  lambdas(5) = -dTheta;
  lambdas(6) = dTheta;

  z3 = zeros(3,1);
  q0 = (1 / (sqrt(2) * norm(b))) * [b; b];
  q1 = (1 / (sqrt(2) * norm(b))) * [b; -b];
  q2 = [dTheta * t0 - lambdas(3) * b0;
        dTheta * t1 + lambdas(3) * b1];
  q3 = [dTheta * t0 - lambdas(4) * b0;
        dTheta * t1 + lambdas(4) * b1];
  q4 = [t0 + b0; -t1 + b1];
  q5 = [t0 - b0; -t1 - b1];

  q2 = q2 / norm(q2);
  q3 = q3 / norm(q3);
  q4 = q4 / norm(q4);
  q5 = q5 / norm(q5);

  Q = [q0 q1 q2 q3 q4 q5];

  H = Q * diag(lambdas) * Q';
end
