function [P] = Twist_PK1(state, mu, theta0)
%Gets twist energy's PK1 from state vector

%vertices from state
v0 = state(1:3);
v1 = state(4:6);
v2 = state(7:9);
v3 = state(10:12);
%edges from vertices
e0 = v0 - v1;
e1 = v2 - v1;
e2 = v3 - v2;
%T from edges
T = [e0 - e0'*e1/dot(e1,e1) * e1, e2 - e2'*e1/dot(e1,e1) * e1, e1];

i6 = dot(T(:,1),T(:,2));
i5u = dot(T(:,1),T(:,1));
i5v = dot(T(:,2),T(:,2));
i3 = det(T);
sgn = -sign(i3);

theta = acos(i6/sqrt(i5u*i5v));
thetalen = sgn*theta - theta0;

dpdi6 = -sgn*2*mu*thetalen/(sqrt(i5u*i5v)*sqrt(1 - i6^2/(i5u*i5v)));
annoyVal = sgn*i6*mu*thetalen/((i5u*i5v)^(3/2)*sqrt(1 - i6^2/(i5u*i5v)));
dpdi5u = i5v*annoyVal;
dpdi5v = i5u*annoyVal;

u = [1;0;0];
v = [0;1;0];
di6dT = T*(u*v' + v*u');
di5udT = 2*T*(u*u');
di5vdT = 2*T*(v*v');

P = dpdi6*di6dT + di5udT*dpdi5u + dpdi5v*di5vdT;

end

