function t = Verify_Hessian(PK1,Hessian)
  % generate a random deformation gradient
  F = (rand(3,2) * 100) - 50;

  % normalize each column back to tangent-space
  T = F;
  T(:,1) = T(:,1) / norm(T(:,1));
  T(:,2) = T(:,2) / norm(T(:,2));

  % track whether or not the differences are converging
  previousdiff = inf;
  failed = false;  
  
  Hdirect = Hessian(T);
  Hnumerical = zeros(6,6);
  eps = 1e-2;
  for e = 1:5
    T0 = T;
    P0 = PK1(T0);
    
    i = 1;
    for y = 1:2
      for x = 1:3
        T1 = T;
        T1(x,y) = T1(x,y) + eps;
        P1 = PK1(T1);
        diff = (P1 - P0) / eps;
        
        Hnumerical(:,i) = reshape(diff, 6,1);
        i = i + 1;
      end
    end
  
    Hdiff = Hdirect - Hnumerical;
    diff = norm(Hdiff) / 36;
    
    % see if we stopped converging
    if (diff >= (previousdiff / 2))
        failed = true;
    end
    previousdiff = diff;
    
    fprintf('eps: %.10f \t diff: %.10f\n', eps, diff);
    eps = eps * 0.1;
  end
  if (failed)
      fprintf('Hessian convergence test ***FAILED***\n')
      Hdirect
      Hnumerical
  else
      fprintf('Hessian convergence test ***PASSED***\n')
  end  
end
