function t = Verify_PK1(Psi,PK1)
  % generate a random deformation gradient
  F = (rand(3,2) * 100) - 50;

  % normalize each column back to tangent-space
  T = F;
  T(:,1) = T(:,1) / norm(T(:,1));
  T(:,2) = T(:,2) / norm(T(:,2));

  PK1direct = PK1(T);
  PK1numerical = zeros(3,2);
  eps = 1e-2;
  
  % track whether or not the differences are converging
  previousdiff = inf;
  failed = false;
  
  for e = 1:5
    T0 = T;
    P0 = Psi(T0);
    
    for y = 1:2
      for x = 1:3
        T1 = T;
        T1(x,y) = T1(x,y) + eps;
        
        P1 = Psi(T1);
        diff = (P1 - P0) / eps;
        
        PK1numerical(x,y) = diff;
      end
    end
  
    PK1diff = PK1direct - PK1numerical;
    diff = norm(PK1diff) / 6;
    
    % see if we stopped converging
    if (diff >= (previousdiff / 2))
        failed = true;
    end
    previousdiff = diff;
    
    fprintf('eps: %.10f \t diff: %.10f\n', eps, diff)
    eps = eps * 0.1;
  end
  if (failed)
      fprintf('PK1 convergence test ***FAILED***\n')
      PK1direct
      PK1numerical
  else
      fprintf('PK1 convergence test ***PASSED***\n')
  end
end
