function t = Verify_Twist_W(W, dWdX)

%Generate a random starting state
state = rand(12,1);
%initialize any old mu and theta0

%calculate the analytic position derivative
derivativeDirect = dWdX(state);

derivativeNumerical = zeros(9,12);
eps = 1e-2;

% track whether or not the differences are converging
previousdiff = inf;
failed = false;

for iter = 1:5
    state0 = state;
    T0 = W(state0);
    
    for i = 1:12
        state1 = state0;
        state1(i) = state1(i) + eps;
        T1 = W(state1);
        diff = (T1 - T0)/eps;

        derivativeNumerical(:,i) = reshape(diff,9,1);
    end
    
    derivativeDiff = derivativeDirect - derivativeNumerical;
    diff = norm(derivativeDiff)/(12*9);

    % see if we stopped converging
    if (diff >= (previousdiff / 2))
        failed = true;
    end
    previousdiff = diff;
    
    fprintf('eps: %.10f \t diff: %.10f\n', eps, diff)
    eps = eps * 0.1;
end

if (failed)
    fprintf('twistT derivative convergence test ***FAILED***\n')
    derivativeDirect
    derivativeNumerical
else
    fprintf('twistT derivative convergence test ***PASSED***\n')
end

end

